@@ -32,7 +32,24 @@ sub should_inline_value
 {
   #my($self, $db, $value) = @_;
   return ($_[1]->validate_date_keyword($_[2]) && 
-          ($_[1]->driver eq 'Informix' || $_[2] =~ /^\w+\(.*\)$/)) ? 1 : 0;
+          ($_[1]->driver eq 'informix' || $_[2] =~ /^\w+\(.*\)$/)) ? 1 : 0;
+}
+
+sub method_should_set
+{
+  my($self, $type, $args) = @_;
+
+  return 1  if($type eq 'set');
+  return 0  if($type eq 'get');
+
+  if($type eq 'get_set')
+  {
+    # Set with 1 arg, but two args is a form of get.
+    # Three or more args is undefined...
+    return @$args == 2 ? 1 : 0;
+  }
+
+  return $self->SUPER::method_should_set($type, $args);
 }
 
 sub parse_value
@@ -51,6 +68,13 @@ sub parse_value
 
 sub format_value { shift; shift->format_date(@_) }
 
+sub method_uses_formatted_key
+{
+  my($self, $type) = @_;
+  return 1  if($type eq 'get' || $type eq 'set' || $type eq 'get_set');
+  return 0;
+}
+
 1;
 
 __END__
